import { DatePicker, Table } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import dayjs from 'dayjs';
import React, { useState } from 'react';
import styles from './index.less';
import BlueTable from '@/components/BlueTable';

type TabKey = 'all' | 'bridge' | 'road';

interface DataType {
  key: string;
  facilityName: string;
  location: string;
  damageSize: string;
  isMajorDamage: string;
  isUrgentDamage: string;
  damageType: string;
  maintenanceType: string;
  repairSize: string;
  completionDate: string;
}

const BridgeMaintenanceList: React.FC = () => {
  const [activeTab, setActiveTab] = useState<TabKey>('all');
  const [dateRange, setDateRange] = useState<[dayjs.Dayjs, dayjs.Dayjs]>([
    dayjs().startOf('month'),
    dayjs().endOf('month')
  ]);

  const columns: ColumnsType<DataType> = [
    {
      title: '设施名称',
      dataIndex: 'facilityName',
      key: 'facilityName',
    },
    {
      title: '病害位置',
      dataIndex: 'location',
      key: 'location',
    },
    {
      title: '病害大小',
      dataIndex: 'damageSize',
      key: 'damageSize',
    },
    {
      title: '是否重大病害',
      dataIndex: 'isMajorDamage',
      key: 'isMajorDamage',
    },
    {
      title: '是否紧急病害',
      dataIndex: 'isUrgentDamage',
      key: 'isUrgentDamage',
    },
    {
      title: '病害类型',
      dataIndex: 'damageType',
      key: 'damageType',
    },
    {
      title: '维护类型',
      dataIndex: 'maintenanceType',
      key: 'maintenanceType',
    },
    {
      title: '维修大小',
      dataIndex: 'repairSize',
      key: 'repairSize',
    },
    {
      title: '维修完成日期',
      dataIndex: 'completionDate',
      key: 'completionDate',
    },
  ];

  const data: DataType[] = Array.from({ length: 10 }, (_, index) => ({
    key: (index + 1).toString(),
    facilityName: '--------',
    location: '--------',
    damageSize: '--------',
    isMajorDamage: '--------',
    isUrgentDamage: '--------',
    damageType: '--------',
    maintenanceType: '--------',
    repairSize: '--------',
    completionDate: '--------',
  }));

  return (
    <div className={styles.container}>
      <div className={styles.content}>
        <div className={styles.filterArea}>
            <DatePicker.RangePicker
            value={dateRange}
            onChange={(dates) => setDateRange(dates as [dayjs.Dayjs, dayjs.Dayjs])}
            className={styles.datePicker}
            format="YYYY年MM月DD日"
            placeholder={['开始日期', '结束日期']}
            suffixIcon={null}
            />
            <div className={styles.tabGroup}>
            <div
                className={`${styles.tabBtn} ${activeTab === 'all' ? styles.active : ''}`}
                onClick={() => setActiveTab('all')}
            >
                全部
            </div>
            <div
                className={`${styles.tabBtn} ${activeTab === 'bridge' ? styles.active : ''}`}
                onClick={() => setActiveTab('bridge')}
            >
                桥梁
            </div>
            <div
                className={`${styles.tabBtn} ${activeTab === 'road' ? styles.active : ''}`}
                onClick={() => setActiveTab('road')}
            >
                道路
            </div>
            </div>
        </div>

        <div className={styles.tableAreaBlue}>
            <BlueTable
                columns={columns}
                scroll={{ y: 500 }}
                dataSource={data}
                pagination={{
                    total: 30,
                    pageSize: 10,
                    current: 1,
                    size: 'small',
                    // className: styles.pagination,
                    showSizeChanger: false,
                }}
            // className={styles.table}
            />
        </div>
      </div>
    </div>
  );
};

export default BridgeMaintenanceList; 