import React from 'react';
import { Flex } from 'antd';
import EChartsReact from 'echarts-for-react';
import * as echarts from 'echarts';
import styles from './index.less';
import { useBridgeManage } from '../../context';

const BridgeAreaDistribution: React.FC = () => {
    const { viewType, isUsingValue } = useBridgeManage();

    // 根据viewType显示不同的数据
    const areaData = {
        bridge: [
        { name: isUsingValue ? '高新区' : '--区', value: isUsingValue ? 152 : '--' },
        { name: isUsingValue ? '天府新区' : '--区', value: isUsingValue ? 152 : '--' },
        { name: isUsingValue ? '锦江区' : '--区', value: isUsingValue ? 152 : '--' },
        { name: isUsingValue ? '青羊区' : '--区', value: isUsingValue ? 152 : '--' },
        { name: isUsingValue ? '金牛区' : '--区', value: isUsingValue ? 152 : '--' },
        { name: isUsingValue ? '武侯区' : '--区', value: isUsingValue ? 152 : '--' }
        ],
        road: [
        { name: isUsingValue ? '高新区' : '--区', value: isUsingValue ? 252 : '--' },
        { name: isUsingValue ? '天府新区' : '--区', value: isUsingValue ? 252 : '--' },
        { name: isUsingValue ? '锦江区' : '--区', value: isUsingValue ? 252 : '--' },
        { name: isUsingValue ? '青羊区' : '--区', value: isUsingValue ? 252 : '--' },
        { name: isUsingValue ? '金牛区' : '--区', value: isUsingValue ? 252 : '--' },
        { name: isUsingValue ? '武侯区' : '--区', value: isUsingValue ? 252 : '--' }
        ]
    };

  const barOption = {
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
    //   top: '3%',
      top: '10%',
      containLabel: true
    },
    xAxis: {
      type: 'category',
    //   data: areaData.map(item => item.name),    
      data: areaData[viewType === 'road' ? 'road' : 'bridge'].map(item => item.name),
        axisLabel: {
        color: '#E4EDFF',
        fontSize: 20,
        interval: 0,
        // rotate: 45,
        },
      axisLine: {
        show: false
      },
      axisTick: {
        show: false
      }
    },
    yAxis: {
      type: 'value',
      splitLine: {
        show: false
      },
      axisLabel: {
        show: false
      },
      axisLine: {
        show: false
      },
      axisTick: {
        show: false
      }
    },
    series: [
      {
        type: 'bar',
        barWidth: 20,
        // data: areaData.map(item => ({
        data: areaData[viewType === 'road' ? 'road' : 'bridge'].map(item => ({
          value: item.value,
          itemStyle: {
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
              { offset: 0.03053, color: 'rgb(177, 180, 255)' },
              { offset: 1, color: 'rgb(109, 99, 255)' }
            ]),
            borderRadius: [15, 15, 15, 15]
          }
        })),
        label: {
          show: true,
          position: 'top',
          color: '#fff',
          fontSize: 20,
          fontFamily: 'D-DIN',
          formatter: (params: any) => {
            return viewType === 'road' ? `${params.value}` : `${params.value}`;
            // return viewType === 'road' ? `${params.value}万m²` : `${params.value}座`;
          }
        },
        // emphasis: {
        //   itemStyle: {
        //     color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
        //       { offset: 0, color: 'rgba(89, 238, 255, 1)' },
        //       { offset: 1, color: 'rgba(89, 238, 255, 0.2)' }
        //     ])
        //   }
        // }
      }
    ]
  };

  const title = viewType === 'road' ? '道路区域分布' : '桥梁区域分布';
  const unit = viewType === 'road' ? '万m²' : '座';

  return (
    <div className={styles.container}>
      <div className={styles.header}>
        <div className={styles.title}>{title}</div>
      </div>
      <div className={styles.unit}>单位：{unit}</div>

      <div className={styles.chart}>
        <EChartsReact 
          option={barOption}
          style={{ height: 220, width: '623px' }}
        />
      </div>
    </div>
  );
};

export default BridgeAreaDistribution; 