import React, { useState } from 'react';
import { Flex, Space } from 'antd';
import styles from './index.less';
import { useBridgeManage } from '../../context';

type TabKey = 'month' | 'year';

const BridgeMaintenance: React.FC = () => {
  const [activeTab, setActiveTab] = useState<TabKey>('month');
  const { viewType, isUsingValue } = useBridgeManage();
  
  const tabLabels: Record<TabKey, string> = {
    month: '本月',
    year: '本年'
  };

  const tabs: TabKey[] = ['month', 'year'];

  const data = {
    bridge: {
      title: '桥梁维护情况',
      subtitle: '巡查发现桥梁病害',
      subtitleCount: isUsingValue ? 182 : '--',
      topTitle: '桥梁病害类型TOP3',
      items: [
        { label: '破损', value: isUsingValue ? 456 : '--', percent: isUsingValue ? 69.5 : '--' },
        { label: '松动', value: isUsingValue ? 456 : '--', percent: isUsingValue ? 69.5 : '--' },
        { label: '移位', value: isUsingValue ? 456 : '--', percent: isUsingValue ? 69.5 : '--' }
      ]
    },
    road: {
      title: '道路维护情况',
      subtitle: '巡查发现道路病害',
      subtitleCount: isUsingValue ? 182 : '--',
      topTitle: '道路病害类型TOP3',
      items: [
        { label: '破损', value: isUsingValue ? 456 : '--', percent: isUsingValue ? 69.5 : '--' },
        { label: '松动', value: isUsingValue ? 456 : '--', percent: isUsingValue ? 69.5 : '--' },
        { label: '移位', value: isUsingValue ? 456 : '--', percent: isUsingValue ? 69.5 : '--' }
      ]
    }
  };
  const currentData = data[viewType === 'road' ? 'road' : 'bridge'];

  return (
    <div className={styles.container}>
      <div className={styles.header}>
      <div className={styles.title}>{currentData.title}</div>
        <div className={styles.tabWrapper}>
          <Space size={10}>
            {tabs.map(tab => (
              <div
                key={tab}
                className={`${styles.tabBtn} ${activeTab === tab ? styles.active : ''}`}
                onClick={() => setActiveTab(tab)}
              >
                {tabLabels[tab]}
              </div>
            ))}
          </Space>
        </div>
      </div>

      <div className={styles.subTitle}>
        <span>{currentData.subtitle}</span>
        <span className={styles.count}>{currentData.subtitleCount}</span>
        <span className={styles.unit}>件</span>
      </div>

      <div className={styles.content}>
        <div className={styles.section}>
        <div className={styles.sectionTitle}>{currentData.topTitle}</div>
          <div className={styles.items}>
            {currentData.items.map((item, index) => (
              <div key={index} className={styles.item}>
                <div className={styles.info}>
                  <span className={styles.label}>{item.label}</span>
                  <span className={styles.value}>{item.value}</span>
                  <span className={styles.unit}>件</span>
                  <span className={styles.percentValue}>{item.percent}</span>
                  <span className={styles.percent}>%</span>
                </div>
                <div className={styles.progress}>
                  <div className={styles.bar} style={{ width: `${item.percent}%` }} />
                </div>
              </div>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};

export default BridgeMaintenance; 