import React, { useState } from 'react';
import { Flex, Space } from 'antd';
import EChartsReact from 'echarts-for-react';
import styles from './index.less';
import { useBridgeManage } from '../../context';

const BridgeTrend: React.FC = () => {
  const [activeYear, setActiveYear] = useState('2024');
  const { viewType, isUsingValue } = useBridgeManage();

  const years = ['2022', '2023', '2024'];
  
  const data = {
    bridge: {
      title: '桥梁检测',
      legend: ['常规定期检测', '结构定期检测', '特殊检测', '应急检测'],
      yAxisLabels: ['A', 'B', 'C', 'D', 'E', '合格', '不合格']
    },
    road: {
      title: '道路检测',
      legend: ['道路定期检测', '特殊检测', '应急检测'],
      yAxisLabels: ['A', 'B', 'C', 'D', 'E'],
    }
  };
  
  const currentData = data[viewType === 'road' ? 'road' : 'bridge'];
  
  const barOption = {
    color: ['#56A8FF', '#00DD97', '#FFDC00', '#FF9E00'],
    legend: {
      data: currentData.legend,
      textStyle: {
        color: '#CBEDFF',
        fontSize: 16
      },
      itemWidth: 12,
      itemHeight: 12,
      itemGap: 24,
      top: 0
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '8%',
      top: '15%',
      containLabel: true
    },
    xAxis: {
      type: 'category',
      data: currentData.yAxisLabels,
      axisLabel: {
        color: '#E4EDFF',
        fontSize: 20
      },
      axisLine: {
        show: false
      },
      axisTick: {
        show: false
      }
    },
    yAxis: {
      type: 'value',
      splitLine: {
        show: false
      },
      axisLabel: {
        show: false
      },
      axisLine: {
        show: false
      },
      axisTick: {
        show: false
      }
    },    
    series: currentData.legend.map(name => ({
        name,
        type: 'bar',
        stack: 'total',
        barWidth: 20,
        emphasis: {
          focus: 'series'
        },
        data: isUsingValue ? [320, 302, 301, 334, 390, 330, 30] : ['--', '--', '--', '--', '--', '--', '--']
      }))
    // series: [
    //   {
    //     name: '常规定期检测',
    //     type: 'bar',
    //     stack: 'total',
    //     barWidth: 12,
    //     data: [20, 15, 18, 25, 20, 30, 15]
    //   },
    //   {
    //     name: '结构定期检测',
    //     type: 'bar',
    //     stack: 'total',
    //     barWidth: 12,
    //     data: [15, 20, 12, 18, 15, 25, 20]
    //   },
    //   {
    //     name: '特殊检测',
    //     type: 'bar',
    //     stack: 'total',
    //     barWidth: 12,
    //     data: [25, 10, 15, 20, 25, 15, 10]
    //   },
    //   {
    //     name: '应急检测',
    //     type: 'bar',
    //     stack: 'total',
    //     barWidth: 12,
    //     data: [10, 25, 20, 15, 10, 20, 25]
    //   }
    // ]
  };

  return (
    <div className={styles.container}>
      <Flex justify="space-between" align="center" className={styles.header}>
        <div className={styles.title}>{currentData.title}</div>
        <Space size={10}>
          {years.map(year => (
            <div
              key={year}
              className={`${styles.yearBtn} ${activeYear === year ? styles.active : ''}`}
              onClick={() => setActiveYear(year)}
            >
              {year}年
            </div>
          ))}
        </Space>
      </Flex>

      <div className={styles.chart}>
        <EChartsReact 
          option={barOption}
          style={{ height: 270, width: '665px' }}
        />
      </div>
    </div>
  );
};

export default BridgeTrend; 