import React, { useRef, useState } from 'react';
import { Flex } from 'antd';
import { RightOutlined } from '@ant-design/icons';
import CooglMap from '@/components/CooglMap';
import styles from './index.less';
import { useBridgeManage } from '../../context';
import type { ViewType } from '../../context';
import locationIcon from '@/assets/images/location.png';
import bridge1Icon from '@/assets/images/brdige/bridge1.png';
import bridge2Icon from '@/assets/images/brdige/bridge2.png';
import bridge3Icon from '@/assets/images/brdige/bridge3.png';
import bridge4Icon from '@/assets/images/brdige/bridge4.png';
import bridge5Icon from '@/assets/images/brdige/bridge5.png';

interface MapBaseProps {
  type?: ViewType;
}

const MapBase: React.FC<MapBaseProps> = ({ type = 'bridge' }) => {
  const { viewType, setViewType, isUsingValue } = useBridgeManage();
  const mapRef = useRef<any>();
  const [isListCollapsed, setIsListCollapsed] = useState(false);
  
  const tabs = [
    { key: 'bridge' as ViewType, label: '桥梁分布' },
    { key: 'road' as ViewType, label: '道路分布' },
    { key: 'location' as ViewType, label: '桥梁位置分布' }
  ];

  // 根据viewType显示不同的信息
  const mapInfo = {
    bridge: {
      centerCity: isUsingValue ? '1242座' : '--',
      suburbs: isUsingValue ? '801座' : '--',
      total: isUsingValue ? '2043座' : '--',
      area: isUsingValue ? '747万m2' : '--'
    },
    road: {
      cityNew: isUsingValue ? '1242万m2' : '--',
      centerCity: isUsingValue ? '801万m2' : '--',
      countyNew: isUsingValue ? '801万m2' : '--',
      area: isUsingValue ? '2043万m2' : '--',
      length: isUsingValue ? '747 KM' : '--',
      count: isUsingValue ? '15625条' : '--'
    },
    location: {
      centerCity: isUsingValue ? '1242座' : '--',
      suburbs: isUsingValue ? '801座' : '--',
      total: isUsingValue ? '2043座' : '--',
      area: isUsingValue ? '747万m2' : '--'
    }
  }[viewType];

  // 不同类型的点位数据
  const pointsData: Record<ViewType, Array<{
    id: number;
    name: string;
    position: [number, number];
    status: 'normal' | 'warning';
  }>> = {
    bridge: [
      { id: 1, name: '天府大道桥', position: [104.06476, 30.657422], status: 'normal' },
      { id: 2, name: '双流大桥', position: [103.92392, 30.574086], status: 'warning' }
    ],
    road: [
      { id: 1, name: '天府大道', position: [104.06476, 30.657422], status: 'normal' },
      { id: 2, name: '人民南路', position: [104.07392, 30.654086], status: 'warning' }
    ],
    location: [
      { id: 1, name: '锦江区桥梁', position: [104.08476, 30.657422], status: 'normal' },
      { id: 2, name: '武侯区桥梁', position: [104.05392, 30.654086], status: 'warning' }
    ]
  };

  // 桥梁列表数据
  const bridgeList = [
    { name: '桥梁名称...', location: 'XXXXXXXXXXXXXX' },
    { name: '桥梁名称...', location: 'XXXXXXXXXXXXXX' },
    { name: '桥梁名称...', location: 'XXXXXXXXXXXXXX' },
    { name: '桥梁名称...', location: 'XXXXXXXXXXXXXX' },
    { name: '桥梁名称...', location: 'XXXXXXXXXXXXXX' },
    { name: '桥梁名称...', location: 'XXXXXXXXXXXXXX' }
  ];

  // 监测统计数据
  const monitorStats = [
    { name: '已接入监测', count: isUsingValue ? 50 : '--', unit: '座', icon: bridge1Icon },
    { name: '正常', count: isUsingValue ? 50 : '--', unit: '', icon: bridge2Icon },
    { name: '黄色预警', count: isUsingValue ? 0 : '--', unit: '', icon: bridge3Icon },
    { name: '橙色预警', count: isUsingValue ? 0 : '--', unit: '', icon: bridge4Icon },
    { name: '红色预警', count: isUsingValue ? 0 : '--', unit: '', icon: bridge5Icon }
  ];

  return (
    <div className={styles.container}>
      <div className={styles.tabBar}>
        <Flex gap={10}>
          {tabs.map(tab => (
            <div
              key={tab.key}
              className={`${styles.tabBtn} ${viewType === tab.key ? styles.active : ''}`}
              onClick={() => setViewType(tab.key)}
            >
              {tab.label}
            </div>
          ))}
        </Flex>
      </div>

      {viewType !== 'location' && (
      <div className={`${styles.mapInfo} ${viewType === 'bridge' ? styles.mapInfo : styles.mapInfoRoad}`}>
        <Flex vertical gap={8}>
            {viewType === 'bridge'  ? (
            <>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>中心城区：</span>
                <span className={styles.value}>{mapInfo.centerCity}</span>
                </Flex>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>郊县：</span>
                <span className={styles.value}>{mapInfo.suburbs}</span>
                </Flex>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>合计：</span>
                <span className={styles.value}>{mapInfo.total}</span>
                </Flex>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>面积：</span>
                <span className={styles.value}>{mapInfo.area}</span>
                </Flex>
            </>
            ) : (
            <>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>城市新区：</span>
                <span className={styles.value}>{mapInfo.cityNew}</span>
                </Flex>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>中心城区：</span>
                <span className={styles.value}>{mapInfo.centerCity}</span>
                </Flex>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>郊县：</span>
                <span className={styles.value}>{mapInfo.countyNew}</span>
                </Flex>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>面积：</span>
                <span className={styles.value}>{mapInfo.area}</span>
                </Flex>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>长度：</span>
                <span className={styles.value}>{mapInfo.length}</span>
                </Flex>
                <Flex align="start" className={styles.infoItem}>
                <span className={styles.label}>数量：</span>
                <span className={styles.value}>{mapInfo.count}</span>
                </Flex>
            </>
            )}
        </Flex>
      </div>
      )}


        <CooglMap.MapView
          ref={mapRef}
          zoom={8}
          center={{ x: 103.96, y: 30.658842 }}
          mode="3D"
        >
          {/* {pointsData[viewType].map(point => (
            <CooglMap.CustomOverlay
              key={point.id}
              position={point.position}
              onClick={() => {
                console.log('点击:', point.name);
              }}
            >
              <div className={styles.marker}>
                <div className={styles.markerContent}>
                  {point.name}
                </div>
                <div className={`${styles.markerIcon} ${styles[point.status]}`} />
              </div>
            </CooglMap.CustomOverlay>
          ))} */}
        </CooglMap.MapView>

        {/* 桥梁位置分布特有的底部监测统计 */}
        {viewType === 'location' && (
          <div className={styles.monitorStats}>
            <Flex align="center" justify="center">
              {monitorStats.map((stat, index) => (
                <Flex key={index} align="center" className={styles.statGroup}>
                  <div className={`${styles.icon} ${index === 0 ? styles.largeIcon : ''}`}>
                    <img src={stat.icon} alt={stat.name} />
                  </div>
                  <span className={styles.name}>{stat.name}</span>
                  <Flex align="center" className={styles.valueWrapper}>
                    <span className={`${styles.count} ${styles[`count${index}`]}`}>
                      {stat.count}
                    </span>
                    {stat.unit && <span className={styles.unit}>{stat.unit}</span>}
                  </Flex>
                </Flex>
              ))}
            </Flex>
          </div>
        )}
     

      {/* 桥梁位置分布特有的右侧列表 */}
      {viewType === 'location' && (
        <>
          {/* 收起按钮独立放置 */}
          <div 
            className={`${styles.collapseBtn} ${isListCollapsed ? styles.collapsed : ''}`}
            onClick={() => setIsListCollapsed(!isListCollapsed)}
          >
            {!isListCollapsed &&(
            <div className={styles.btnText}>
              <span>收</span>
              <span>起</span>
            </div>
            )}
            <RightOutlined className={styles.collapseIcon} />
          </div>

          {/* 列表内容 */}
          <div className={`${styles.bridgeList} ${isListCollapsed ? styles.collapsed : ''}`}>
            <div className={styles.listHeader}>
              <span>桥梁列表</span>
            </div>
            <div className={styles.listContent}>
              {bridgeList.map((bridge, index) => (
                <div key={index} className={styles.bridgeItem}>
                  <span className={styles.bridgeName}>{bridge.name}</span>
                  <div className={styles.locationIcon}>
                    <img src={locationIcon} alt="location icon" style={{ width: '10px', height: '11px' }} />
                  </div>
                </div>
              ))}
            </div>
          </div>
        </>
      )}
    </div>
  );
};

export default MapBase; 