import React from 'react';
import styles from './index.less';

interface InfoItemProps {
  value: string | number;
  label: string;
  unit: string;
}
let isUsingValue = false;
const showValue = (value: number | string) => {
  if(isUsingValue){
    return value;
  }
  return '--';
}

const InfoItem: React.FC<InfoItemProps> = ({ value, label, unit }) => (
  <div className={styles.infoItem}>
    <div className={styles.valueWrapper}>
      <span className={styles.value}>{showValue(value)}</span>
      <span className={styles.unit}>{unit}</span>
    </div>
    <div className={styles.label}>{label}</div>
  </div>
);

interface DisposalSiteInfoProps {
  searchTime: {
    startTime: string;
    endTime: string;
  };
}

const DisposalSiteInfo: React.FC<DisposalSiteInfoProps> = ({ searchTime }) => {
  const infoData = [
    {
      value: 482,
      label: '固定式建筑垃圾消纳场数量',
      unit: '个'
    },
    {
      value: 482,
      label: '临时性建筑垃圾转动调配场数量',
      unit: '个'
    },
    {
      value: 482.21,
      label: '总容量',
      unit: '万方'
    },
    {
      value: 482.54,
      label: '剩余库容',
      unit: '万方'
    }
  ];

  return (
    <div className={styles.container}>
      <div className={styles.title}>消纳场概况</div>
      <div className={styles.content}>
        {infoData.map((item, index) => (
          <InfoItem key={index} {...item} />
        ))}
      </div>
    </div>
  );
};

export default DisposalSiteInfo; 