import React, { useState, useEffect, useRef } from 'react';
import * as echarts from 'echarts';
import styles from './index.less';
import { Tabs } from 'antd';

interface DistributionChartProps {
  searchTime: {
    startTime: string;
    endTime: string;
  };
}

const DistributionChart: React.FC<DistributionChartProps> = ({ searchTime }) => {
  const chartRef = useRef<HTMLDivElement>(null);
  const [activeTab, setActiveTab] = useState('1');

  const tabItems = [
    {
      key: '1',
      label: '建筑垃圾申报排放量区域分布',
    },
    {
      key: '2',
      label: '疑似违规倾倒点位区域分布',
    },
  ];

  let isUsingValue = false;

  useEffect(() => {
    if (!chartRef.current) return;
    
    const chart = echarts.init(chartRef.current);
    
    // 模拟数据
    const data = Array(22).fill(0).map(() => ({
      wasteAmount: isUsingValue?Math.floor(Math.random() * 200 + 100):0,
      siteCount: isUsingValue?Math.floor(Math.random() * 20 + 10):0,
    }));

    const maxValue = 300; // 固定背景柱的长度

    const option = {
      tooltip: {
        trigger: 'axis',
        backgroundColor: 'rgba(8, 24, 63, 0.9)',
        borderColor: '#13659680',
        borderWidth: 1,
        textStyle: {
          color: '#BCCEE9'
        }
      },
      grid: {
        left: '1%',
        right: '3%',
        bottom: '3%',
        top: '20%',
        containLabel: true
      },
      xAxis: {
        type: 'category',
        data: ['锦江区', '青羊区', '金牛区', '武侯区', '成华区', '龙泉驿区', '青白江区', '新都区', '温江区', '双流区', '郫都区', '新津区', '简阳市', '都江堰市', '彭州市', '邛崃市', '崇州市', '金堂县', '大邑县', '蒲江县', '新津县'],        
        axisLine: {
          show: false
        },
        // axisLine: {
        //   lineStyle: {
        //     color: 'rgba(255, 255, 255, 0.1)'
        //   }
        // },
        axisLabel: {
          color: '#E4EDFF',
          fontSize: 20,
          interval: 0,
        }
      },
      yAxis: {
        type: 'value',
        max: maxValue,
        nameTextStyle: {
          color: '#BCCEE9',
          fontSize: 16,
          padding: [0, 0, 0, 50]
        },
        splitLine: {
          show: false
        },
        axisLine: {
          show: false
        },
        axisTick: {
          show: false
        },
        axisLabel: {
          show: true,
          color: '#E4EDFF',
          fontSize: 16,
          // interval: 0,
        }
      },
      series: [
        {
          type: 'bar',
          barWidth: 20,
          z: 1,
          barGap: '-100%',
          data: data.map(() => ({
            value: maxValue,
            itemStyle: {
              color: '#33658D',
              // color: 'rgba(57, 122, 183, 0.2)',
              borderRadius: [15, 15, 15, 15]
            }
          }))
        },
        {
          type: 'bar',
          barWidth: 20,
          z: 2,
          barGap: '-100%',
          data: data.map(item => ({
            value: activeTab === '1' ? item.wasteAmount : item.siteCount,
            itemStyle: {
              color: activeTab === '1' ? 'rgba(89, 238, 255, 0.6)' : '#FFB36B',
              borderRadius: [15, 15, 15, 15]
            }
          })),
          label: {
            show: true,
            position: 'top',
            color: '#E4EDFF',
            fontSize: 20,
            formatter: (params: any) => {
              return params.value;
            }
          }
        }
      ]
    };

    chart.setOption(option);

    return () => {
      chart.dispose();
    };
  }, [activeTab]);

  return (
    <div className={styles.container}>
      <Tabs
        className={styles.tabs}
        activeKey={activeTab}
        onChange={setActiveTab}
        items={tabItems}
      />
      <div className={styles.chartWrapper}>
        <div className={styles.yAxisLabel}>单位：{activeTab === '1' ? '万方' : '个'}</div>
        <div ref={chartRef} style={{ width: '100%', height: '100%' }} />
      </div>
    </div>
  );
};

export default DistributionChart; 