import React from 'react';
import styles from './index.less';

interface InfoItemProps {
  value: string | number;
  label: string;
  unit: string;
}

let isUsingValue = false;
const showValue = (value: number | string) => {
  if(isUsingValue){
    return value;
  }
  return '--';
}
const InfoItem: React.FC<InfoItemProps> = ({ value, label, unit }) => (
  <div className={styles.infoItem}>
    <div className={styles.valueWrapper}>
      <span className={styles.value}>{showValue(value)}</span>
      <span className={styles.unit}>{unit}</span>
    </div>
    <div className={styles.label}>{label}</div>
  </div>
);

interface RecyclingInfoProps {
  searchTime: {
    startTime: string;
    endTime: string;
  };
}

const RecyclingInfo: React.FC<RecyclingInfoProps> = ({ searchTime }) => {
  const topData = [
    {
      value: 12,
      label: '固定式建筑垃圾资源化利用厂',
      unit: '个'
    },
    {
      value: 12,
      label: '临时性建筑垃圾资源化利用厂',
      unit: '个'
    },
    {
      value: 1200,
      label: '处置能力',
      unit: '万吨/年'
    }
  ];

  const bottomData = [
    {
      value: 112,
      label: '综合利用点数量',
      unit: '个'
    },
    {
      value: 12,
      label: '综合利用处置量',
      unit: '万方'
    }
  ];

  return (
    <div className={styles.container}>
      <div className={styles.topSection}>
        <div className={styles.title}>资源化利用厂概况</div>
        <div className={styles.content}>
          {topData.map((item, index) => (
            <InfoItem key={index} {...item} />
          ))}
        </div>
      </div>
      <div className={styles.bottomSection}>
        <div className={styles.title}>综合利用点概况</div>
        <div className={styles.content1}>
          {bottomData.map((item, index) => (
            <InfoItem key={index} {...item} />
          ))}
        </div>
      </div>
    </div>
  );
};

export default RecyclingInfo; 