import React, { useState } from 'react';
import { Flex } from 'antd';
import { DatePicker } from 'antd';
import dayjs from 'dayjs';
import styles from './index.less';
import BlueTable from '@/components/BlueTable';
import type { ColumnsType } from 'antd/es/table';

interface AlarmDataType {
  alarmTime: string;
  deviceName: string;
  alarmType: string;
  description: string;
  status: string;
  closeTime: string;
}

const LightingAlarmList: React.FC = () => {
  const [dateRange, setDateRange] = useState<[dayjs.Dayjs, dayjs.Dayjs]>([
    dayjs().startOf('month'),
    dayjs().endOf('month')
  ]);
  const [alarmStatus, setAlarmStatus] = useState('all');
  let isUsingValue = true;

  const columns: ColumnsType<AlarmDataType> = [
    {
      title: '告警时间',
      dataIndex: 'alarmTime',
      key: 'alarmTime',
      width: 250,
      className: styles.tableCell
    },
    {
      title: '告警设备',
      dataIndex: 'deviceName',
      key: 'deviceName',
      width: 200,
      className: styles.tableCell
    },
    {
      title: '告警详细类型',
      dataIndex: 'alarmType',
      key: 'alarmType',
      width: 250,
      className: styles.tableCell
    },
    {
      title: '告警描述',
      dataIndex: 'description',
      key: 'description',
      width: 300,
      className: styles.tableCell
    },
    {
      title: '告警状态',
      dataIndex: 'status',
      key: 'status',
      width: 150,
        render: (status: string) => (
        <span className={status === '告警中' ? styles.statusWarning : styles.statusClosed}>{status}</span>
        )
    },
    {
      title: '告警关闭时间',
      dataIndex: 'closeTime',
      key: 'closeTime',
      width: 250,
      className: styles.tableCell
    }
  ];

  const mockData: AlarmDataType[] = isUsingValue
    ? Array.from({ length: 10 }, () => ({
        alarmTime: 'XXXXXXXX',
        deviceName: 'XXXXXXXXX',
        alarmType: 'XXXXXXXXX',
        description: 'XXXXXXXX',
        status: Math.random() > 0.5 ? '告警中' : '关闭',
        closeTime: 'XXXXXXXX'
      }))
    : [];

  return (
    <div className={styles.container}>
      {/* 筛选条件区域 */}
      <div className={styles.filters}>
        <Flex gap={20} align="center">
          {/* <span className={styles.label}>告警时间</span> */}
          <DatePicker.RangePicker
            value={dateRange}
            onChange={(dates) => {
              if (dates && dates[0] && dates[1]) {
                setDateRange([dates[0], dates[1]]);
              }
            }}
            format="YYYY年MM月DD日"
            className={styles.datePicker}
          />
          {/* <span className={styles.label} style={{marginLeft: '40px'}}>告警状态</span> */}
          <div className={styles.facilityTabs}>
            <div 
              className={`${styles.facilityTab} ${alarmStatus === 'all' ? styles.active : ''}`}
              onClick={() => setAlarmStatus('all')}
            >
              全部
            </div>
            <div 
              className={`${styles.facilityTab} ${alarmStatus === 'warning' ? styles.active : ''}`}
              onClick={() => setAlarmStatus('warning')}
            >
              告警中
            </div>
            <div 
              className={`${styles.facilityTab} ${alarmStatus === 'closed' ? styles.active : ''}`}
              onClick={() => setAlarmStatus('closed')}
            >
              关闭
            </div>
          </div>
        </Flex>
      </div>

      {/* 表格区域 */}
      <BlueTable
        columns={columns}
        dataSource={mockData}
        scroll={{ y: 520 }}
        pagination={{
          total: 30,
          pageSize: 10,
        }}
      />
    </div>
  );
};

export default LightingAlarmList; 