import React, { useState } from 'react';
import { Flex, Progress, Select } from 'antd';
import styles from './index.less';
import BlueTable from '@/components/BlueTable';
import type { ColumnsType } from 'antd/es/table';

interface DataType {
  deviceName: string;
  deviceStatus: string;
  lightIntensity: string;
  rainfall: string;
  windDirection: string;
  windSpeed: string;
}

const MonitorTable: React.FC = () => {
  const [activeTab, setActiveTab] = useState('tab1');
  let isUsingValue = true;

  const columns: ColumnsType<DataType> = [
    {
      title: '设备名称',
      dataIndex: 'deviceName',
      key: 'deviceName',
      width: 200,
      className: styles.tableCell
    },
    {
      title: '设备状态',
      dataIndex: 'deviceStatus',
      key: 'deviceStatus',
      width: 120,
      className: styles.tableCell,
      render: (text) => (
        <span className={text === '在线' ? styles.onlineStatus : styles.offlineStatus}>
          {text}
        </span>
      )
    },
    {
      title: '光照度(Lux)',
      dataIndex: 'lightIntensity',
      key: 'lightIntensity',
      width: 150,
      className: styles.tableCell
    },
    {
      title: '雨量(毫米)',
      dataIndex: 'rainfall',
      key: 'rainfall',
      width: 150,
      className: styles.tableCell
    },
    {
      title: '风向(°)',
      dataIndex: 'windDirection',
      key: 'windDirection',
      width: 120,
      className: styles.tableCell
    },
    {
      title: '风速(m/s)',
      dataIndex: 'windSpeed',
      key: 'windSpeed',
      width: 120,
      className: styles.tableCell
    }
  ];

  const mockData: DataType[] = isUsingValue
    ? Array.from({ length: 10 }, () => ({
        deviceName: 'XXXXXXXX',
        deviceStatus: Math.random() > 0.5 ? '在线' : '离线',
        lightIntensity: 'XXXXX',
        rainfall: 'XXXXX',
        windDirection: 'XXXXXXXXXX',
        windSpeed: 'XXXXXXX',
      }))
    : [];

  return (
    <div className={styles.tableSection}>
      {/* <div className={styles.title}>感知设备实时监测信息</div> */}
      <div className={styles.tabs}>
        <div 
          className={`${styles.tab} ${activeTab === 'tab1' ? styles.active : ''}`}
          onClick={() => setActiveTab('tab1')}
        >
          自然光及风雨量监测列表
        </div>
        <div 
          className={`${styles.tab} ${activeTab === 'tab2' ? styles.active : ''}`}
          onClick={() => setActiveTab('tab2')}
        >
          水浸实时监测列表
        </div>
        <div 
          className={`${styles.tab} ${activeTab === 'tab3' ? styles.active : ''}`}
          onClick={() => setActiveTab('tab3')}
        >
          固定光照度监测表
        </div>
      </div>
      <BlueTable
        columns={columns}
        dataSource={mockData}
        scroll={{ y: 520 }}
        pagination={{
          total: 30,
          pageSize: 10,
        }}
      />
    </div>
  );
};

export default MonitorTable; 