import EmptyWithConditions from '@/components/EmptyWithConditions';
import BaseCard from '@/pages/GlobalModalServices/components/BaseCard';
import { CaretDownOutlined } from '@ant-design/icons';
import { Flex, Space } from 'antd';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { memo, useLayoutEffect, useMemo, useRef, useState } from 'react';
import option from './option';

/** @name 故障趋势 */
const Trend: React.FC = memo(() => {
  const [dataSource, setDataSource] = useState({
    list: [
      {
        name: '01-01',
        value: 100,
      },
      {
        name: '01-02',
        value: 100,
      },
      {
        name: '01-03',
        value: 100,
      },
      {
        name: '01-04',
        value: 100,
      },
    ],
  });
  const chartRef = useRef<any>();
  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const LineOption = useMemo(() => {
    const temp = cloneDeep(option) as any;
    const xAxis = dataSource.list?.map((v) => v.name) ?? [];

    temp.xAxis[0].data = xAxis;

    const lineSeries = [
      {
        name: '功率',
        type: 'line',
        symbol: 'none',
        stack: 'Total',
        lineStyle: {
          color: 'rgb(89, 238, 255)',
          width: 3,
        },
        smooth: true,

        areaStyle: {
          color: {
            type: 'linear',
            x: 0,
            y: 0,
            x2: 0,
            y2: 1,
            colorStops: [
              {
                offset: 0,
                color: 'rgba(89, 238, 255,0.26)', // 0% 处的颜色
              },
              {
                offset: 1,
                color: 'rgba(89, 238, 255, 0)', // 100% 处的颜色
              },
            ],
            global: false, // 缺省为 false
          },
        },
        data:
          dataSource.list?.map((item) => {
            return item.value;
          }) ?? [],
      },
    ];
    temp.series = lineSeries;
    return temp;
  }, [dataSource.list]);
  return (
    <BaseCard
      w={648}
      h={200}
      title="故障趋势"
      headerRight={
        <Space>
          <div>环比</div>
          <Flex>
            <CaretDownOutlined style={{ color: 'rgb(29, 187, 138)' }} />
            <span>--</span>
            <span>%</span>
          </Flex>
        </Space>
      }
    >
      <EmptyWithConditions conditions={true}>
        <EChartsReact
          ref={chartRef}
          style={{
            height: 120,
          }}
          option={LineOption}
        ></EChartsReact>
      </EmptyWithConditions>
    </BaseCard>
  );
});

export default Trend;
