import { Progress } from 'antd';
import ReactEcharts from 'echarts-for-react';
import React, { useRef, useState } from 'react';
import CooglMap from '@/components/CooglMap';
import styles from './index.less';
import livingGarbageIcon from '@/assets/images/livingGarbage.png';
import livingGarbageMap1 from '@/assets/images/livingGarbageMap1.png';
import livingGarbageMap2 from '@/assets/images/livingGarbageMap2.png';
import { RightOutlined, EnvironmentOutlined } from '@ant-design/icons';
import locationIcon from '@/assets/images/location.png';

const LivingGarbage: React.FC = () => {
  const [isListVisible, setIsListVisible] = useState(true);
  const mapRef = useRef<any>();

  let isUsingValue = false;

  // 地图配置
//   const mapConfig = {
//     center: [104.06, 30.67],
//     zoom: 10,
//     minZoom: 9,
//     maxZoom: 18,
//     pitch: 0,
//   };

  // 环形进度图配置
  const getOption = () => ({
    series: [{
      type: 'gauge',
      startAngle: 90,
      endAngle: -270,
      pointer: { show: false },
      progress: {
        show: true,
        overlap: false,
        roundCap: true,
        clip: false,
        itemStyle: {
          color: '#52FF76'
        }
      },
      axisLine: {
        lineStyle: {
          width: 6,
          color: [[1, 'rgba(191, 225, 255, 0.26)']]
        }
      },
      splitLine: { show: false },
      axisTick: { show: false },
      axisLabel: { show: false },
      data: [{ value: 78.56 }],
      detail: { show: false }
    }]
  });

  const disposalList = [
    { name: isUsingValue ? '万兴环保发电二期' : '--', value: isUsingValue ? 22.33 : '--' },
    { name: isUsingValue ? '九江环保发电厂' : '--', value: isUsingValue ? 22.33 : '--' },
    { name: isUsingValue ? '享福环保发电厂' : '--', value: isUsingValue ? 22.33 : '--' },
    { name: isUsingValue ? '宝林环保发电厂' : '--', value: isUsingValue ? 22.33 : '--' },
    { name: isUsingValue ? '隆丰环保发电厂' : '--', value: isUsingValue ? 22.33 : '--' },
    { name: isUsingValue ? '邓双环保发电厂' : '--', value: isUsingValue ? 22.33 : '--' },
    { name: isUsingValue ? '简阳发电厂' : '--', value: isUsingValue ? 22.33 : '--' },
    { name: isUsingValue ? '万兴环保发电厂一期' : '--', value: isUsingValue ? 22.33 : '--' },
    { name: isUsingValue ? '金堂环保发电厂' : '--', value: isUsingValue ? 22.33 : '--' },
  ];

  // 模拟管廊列表数据
  const pipelineList = [
    { name: isUsingValue ? '焚烧厂名称1' : '--', location: { x: 103.96, y: 30.658842 } },
    { name: isUsingValue ? '焚烧厂名称1' : '--', location: { x: 103.96, y: 30.658842 } },
    { name: isUsingValue ? '焚烧厂名称3' : '--', location: { x: 103.96, y: 30.658842 } },
    { name: isUsingValue ? '填埋场1' : '--', location: { x: 103.96, y: 30.658842 } },
    { name: isUsingValue ? '填埋场2' : '--', location: { x: 103.96, y: 30.658842 } },
  ];

  // 定位功能
  const handleLocation = (location: { x: number; y: number }) => {
    mapRef.current?.setCenter([location.x, location.y]);
  };

  return (
    <div className={styles.container}>
      <div className={styles.leftContent}>
        {/* 资源化利用率 */}
        <div className={styles.utilizationRate}>
          <div className={styles.title}>资源化利用率</div>
          <div className={styles.date}>2024年12月</div>
          <div className={styles.value}>{isUsingValue ? 78.56 : '--'}</div>
          <span className={styles.unit}>%</span>
          <div className={styles.chart}>
            <ReactEcharts option={getOption()} style={{height: '55px', width: '55px'}} />
          </div>
        </div>

        {/* 生活垃圾处置情况 */}
        <div className={styles.disposalStatus}>
          <div className={styles.title}>生活垃圾处置情况</div>
          <div className={styles.date}>2024年12月</div>
          
          <div className={styles.totalDisposal}>
            <img src={livingGarbageIcon} alt="垃圾处理" />
            <span className={styles.label}>处置总量</span>
            <span className={styles.value}>{isUsingValue ? 187.25 : '--'}</span>
            <span className={styles.unit}>万吨</span>
          </div>

          <div className={styles.subItems}>
            <div className={styles.item}>
              <div className={styles.label}>焚烧量</div>
              <div className={styles.value}>{isUsingValue ? 17.25 : '--'}</div>
              <span className={styles.unit}>万吨</span>
            </div>
            <div className={styles.item}>
              <div className={styles.label}>填埋量</div>
              <div className={styles.value}>{isUsingValue ? 156.21 : '--'}</div>
              <span className={styles.unit}>万吨</span>
            </div>
          </div>

          <div className={styles.disposalList}>
            <div className={styles.listTitle}>
              生活垃圾焚烧厂处置量
              <span className={styles.unit}>单位：万吨</span>
            </div>
            <div className={styles.listContent}>
              {disposalList.map((item, index) => (
                <div key={index} className={styles.listItem}>
                  <span className={styles.name}>{item.name}</span>
                <Progress 
                  size={{ height: 15 }}
                  percent={Number(item.value)} 
                  showInfo={false}
                  trailColor="rgba(144, 205, 229, 0.22)"
                  strokeColor={{ from: '#79FFD1', to: '#00B9FF' }}
                  className={styles.progress}
                />
                <span className={styles.value}>{isUsingValue ? item.value : '--'}</span>
                </div>
              ))}
            </div>
          </div>
        </div>
      </div>

      <div className={styles.rightContent}>
        <div className={styles.mapContainer}>
          <CooglMap.MapView
            ref={mapRef}
            // {...mapConfig}
            zoom={8}
            center={{ x: 103.96, y: 30.658842 }}
            mode="3D"
          >
            {/* 地图标题 - 移到地图内部 */}
            <div className={styles.mapTitle}>生活垃圾处置厂分布</div>

            <div className={styles.legend}>
              <div className={styles.legendTitle}>图层图例</div>
              <div className={styles.legendItem}>
                <img src={livingGarbageMap1} alt="焚烧厂" />
                <span>焚烧厂</span>
              </div>
              <div className={styles.legendItem}>
                <img src={livingGarbageMap2} alt="填埋场" />
                <span>填埋场</span>
              </div>
            </div>

            {/* 右侧列表 */}            
                {/* 收起按钮独立放置 */}
            <div 
                className={`${styles.collapseBtn} ${!isListVisible ? styles.collapsed : ''}`}
                onClick={() => setIsListVisible(!isListVisible)}
            >
                {isListVisible &&(
                <div className={styles.btnText}>
                <span>收</span>
                <span>起</span>
                </div>
                )}
                <RightOutlined className={styles.collapseIcon} />
            </div>

            <div className={`${styles.listContainer} ${!isListVisible ? styles.collapsed : ''}`}>
              <div className={styles.listHeader}>
                
                <div className={styles.listTitle}>
                  <span>管廊列表</span>
                </div>
              </div>
              <div className={styles.listContent}>
                {pipelineList.map((item, index) => (
                  <div key={index} className={styles.listItem}>
                    <span className={styles.name}>{item.name}</span>
                    <img 
                      src={locationIcon} 
                      className={styles.locationIcon} 
                      onClick={() => handleLocation(item.location)}
                      alt="定位"
                    />
                  </div>
                ))}
              </div>
            </div>
          </CooglMap.MapView>
        </div>
      </div>
    </div>
  );
};

export default LivingGarbage; 