import React, { useState } from 'react';
import { Flex } from 'antd';
import { DatePicker } from 'antd';
import dayjs from 'dayjs';
import styles from './index.less';
import BlueTable from '@/components/BlueTable';
import type { ColumnsType } from 'antd/es/table';

interface DataType {
  planName: string;
  startDate: string;
  endDate: string;
  pipelineName: string;
  inspectionResult: string;
  operation: string;
}

const PipelineInspection: React.FC = () => {
  const [dateRange, setDateRange] = useState<[dayjs.Dayjs, dayjs.Dayjs]>([
    dayjs().startOf('month'),
    dayjs().endOf('month')
  ]);
  let isUsingValue = true;

  const columns: ColumnsType<DataType> = [
    {
      title: '巡检计划名称',
      dataIndex: 'planName',
      key: 'planName',
      width: 300,
      className: styles.tableCell
    },
    {
      title: '开始日期',
      dataIndex: 'startDate',
      key: 'startDate',
      width: 250,
      className: styles.tableCell
    },
    {
      title: '结束日期',
      dataIndex: 'endDate',
      key: 'endDate',
      width: 250,
      className: styles.tableCell
    },
    {
      title: '管廊名称',
      dataIndex: 'pipelineName',
      key: 'pipelineName',
      width: 200,
      className: styles.tableCell
    },
    {
      title: '巡检结果',
      dataIndex: 'inspectionResult',
      key: 'inspectionResult',
      width: 200,
      className: styles.tableCell
    },
    {
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      width: 120,
      render: () => (
        <span className={styles.operation}>详情</span>
      )
    }
  ];

  const mockData: DataType[] = isUsingValue
    ? Array.from({ length: 10 }, () => ({
        planName: 'XXXXXXXX',
        startDate: 'XXXXXXXXX',
        endDate: 'XXXXXXXXX',
        pipelineName: 'XXXXXXXX',
        inspectionResult: 'XXXXXXXX',
        operation: '查看'
      }))
    : [];

  return (
    <div className={styles.container}>
      {/* 筛选条件区域 */}
      <div className={styles.filters}>
        <Flex gap={20} align="center">
          <span className={styles.label}>巡检时间</span>
          <DatePicker.RangePicker
            value={dateRange}
            onChange={(dates) => {
              if (dates && dates[0] && dates[1]) {
                setDateRange([dates[0], dates[1]]);
              }
            }}
            format="YYYY年MM月DD日"
            className={styles.datePicker}
          />
        </Flex>
      </div>

      {/* 表格区域 */}
      <BlueTable
        columns={columns}
        dataSource={mockData}
        scroll={{ y: 520 }}
        pagination={{
          total: 30,
          pageSize: 10,
        }}
      />
    </div>
  );
};

export default PipelineInspection; 