import DescriptionItem from '@/components/DescriptionItem';
import { Flex } from 'antd';
import classNames from 'classnames';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { useLayoutEffect, useMemo, useRef, useState } from 'react';
import BaseCard from '../../../components/BaseCard';
import styles from './index.less';
import option from './option';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';

/** @name 管廊感知态势 */
const PipeCorridorSensesTheSituation: React.FC = () => {
  const chartRef = useRef<any>();
  const [activeTab, setActiveTab] = useState('1');
  const { dispatch } = useGlobalModalServices();

  let isTrigger = true;

  const tabItems = useMemo(
    () => [
      {
        key: '1',
        label: '各类型设备在线率',
      },
      {
        key: '2',
        label: '各类型设备预警数',
      },
    ],
    [],
  );

  const INFO = useMemo(() => {
    return [
      {
        name: '已接入感知设备',
        value: 82,
        unit: '个',
      },
      {
        name: '设备在线率',
        value: 40,
        unit: '%',
        vColor: '#55D355',
      },
      {
        name: '预警数',
        value: 42,
        unit: '个',
        vColor: '#FFB05A',
      },
    ];
  }, []);

  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const BarOption = useMemo(() => {
    const temp = cloneDeep(option) as any;
    const xAxis = [
      '液位监测传感器',
      '湿度传感器',
      '温度传感器',
      '硫化氢气体传感器',
      '甲烷气体传感器',
      '一氧化碳气体传感器',
      '氧气浓度传感器',
    ];

    const yAxis = [1652, 1652, 1652, 1652, 1652, 1652, 1652];
    temp.xAxis[0].data = xAxis;
    temp.series[0].data = yAxis;
    if (activeTab === '1') {
      temp.series[0].itemStyle.color = {
        type: 'linear',
        x: 0,
        y: 0,
        x2: 0,
        y2: 1,
        colorStops: [
          {
            offset: 0,
            color: '#76FDD2', // 0% 处的颜色
          },
          {
            offset: 1,
            color: '#02BAFE', // 100% 处的颜色
          },
        ],
        global: false, // 缺省为 false
      };
    }
    return temp;
  }, [activeTab]);

  return (
    <BaseCard w={917} h={357} title="监测信息 ">
      <Flex gap={100} style={{ marginTop: 20 }} align="center">
        {INFO.map((item) => {
          return (
            <DescriptionItem
              value={item.value}
              direction="horizontal"
              unit={item.unit}
              valueStyle={{
                margin: '0 12px',
                color: item.vColor,
              }}
              name={item.name}
              key={item.name}
              onClick={() => {
                if (isTrigger) {
                  dispatch.push('PipelineMonitor', {
                    // title: `${item.name}综合管廊`,
                  });
                }
              }}
            />
          );
        })}
      </Flex>
      <div>
        <Flex gap={36} style={{ marginTop: 20 }}>
          {tabItems.map((item, index) => {
            return (
              <div
                key={index}
                onClick={() => {
                  setActiveTab(item.key);
                }}
                className={classNames(styles.tabItem, {
                  [styles.active]: activeTab === item.key,
                })}
              >
                {item.label}
              </div>
            );
          })}
        </Flex>
        <EChartsReact
          ref={chartRef}
          style={{
            height: 150,
          }}
          option={BarOption}
        ></EChartsReact>
      </div>
    </BaseCard>
  );
};

export default PipeCorridorSensesTheSituation;
