import { Flex, Popover } from 'antd';
import EChartsReact from 'echarts-for-react';
import { cloneDeep } from 'lodash';
import React, { useLayoutEffect, useMemo, useRef } from 'react';
import BaseCard from '../../../components/BaseCard';
import DescriptionItem from '@/components/DescriptionItem';
import questionMark from '@/assets/images/questionMark.png';
import styles from './index.less';
import option from './option';
import { useGlobalModalServices } from '@/pages/GlobalModalServices/provider';

/** @name 管廊维护情况 */
const PipeGalleryMaintenanceStatus: React.FC = () => {
  const chartRef = useRef<any>();
  const { dispatch } = useGlobalModalServices();

  const INFO = useMemo(() => {
    return [
      {
        name: '本体维护保养',
        value: 82,
        unit: '处',
      },
      {
        name: '附属设施维护保养',
        value: 82,
        unit: '个',
        vColor: '#FFB05A',
      },
    ];
  }, []);

  useLayoutEffect(() => {
    chartRef.current?.resize();
  }, []);

  const LineOption = useMemo(() => {
    const temp = cloneDeep(option) as any;
    const xAxis = [
      '2024年7月',
      '2024年8月',
      '2024年9月',
      '2024年10月',
      '2024年11月',
      '2024年12月',
    ];
    // const yAxis = [1652, 1652, 1652, 1652, 1652, 1652, 1652];
    temp.xAxis[0].data = xAxis;
    temp.grid = {
      // left: '0%',
      // right: '0%',
      // top: '0%',
      bottom: '20%'
    }
    const lineSeries = [
      {
        name: '本体维护保养',
        type: 'line',
        symbol: 'none',
        stack: 'Total',
        lineStyle: {
          color: '#57efe5',
          width: 3,
        },
        smooth: true,
        data: [120, 132, 101, 134, 90, 230, 210],
      },
      {
        name: '附属设施维护保养',
        type: 'line',
        stack: 'Total',
        lineStyle: {
          color: '#FFB05A',
          width: 3,
        },
        smooth: true,
        symbol: 'none',
        data: [220, 182, 191, 234, 290, 330, 310],
      },
    ];
    temp.series = lineSeries;
    return temp;
  }, []);

  const popoverContent = (
    <div className={styles.popoverContent}>
      <div>统计时间范围：</div>
      <div>上月21日到本月20日</div>
    </div>
  );

  return (
    <BaseCard
      w={917}
      h={342}
      headerRight={
        // <div className={styles.time}>2024年12月</div>
        // // <div className={styles.time}>2024年11月 21日 -2024年12月20日</div>
        <div className={styles.timeWrapper} 
        onClick={() => {
          if (false) {
            dispatch.push('PipelineAssessment', {
              // title: `${item.name}综合管廊`,
            });
          }
        }}>
          <span className={styles.time}>2024年12月</span>
          <Popover 
            content={popoverContent}
            placement="bottomRight"
            overlayClassName={styles.customPopover}
          >
            <img src={questionMark} alt="question" className={styles.questionIcon} />
          </Popover>
        </div>
      }
      title="管廊维护情况"
    >
      <Flex gap={100} style={{ marginTop: 20 }} align="center" 
        onClick={() => {
          if (false) {
            dispatch.push('PipelineMaintenance', {
              // title: `${item.name}综合管廊`,
            });
          }
        }}>
        {INFO.map((item) => {
          return (
            <DescriptionItem
              value={item.value}
              direction="horizontal"
              unit={item.unit}
              valueStyle={{
                margin: '0 12px',
                color: item.vColor,
              }}
              name={item.name}
              key={item.name}
            />
          );
        })}
      </Flex>
      <div>
        <div className={styles.chartTitle} 
        onClick={() => {
          if (false) {
            dispatch.push('PipelineInspection', {
              // title: `${item.name}综合管廊`,
            });
          }
        }}>近6个月维护趋势</div>
        <EChartsReact
          ref={chartRef}
          style={{
            height: 140,
          }}
          option={LineOption}
        ></EChartsReact>
      </div>
    </BaseCard>
  );
};

export default PipeGalleryMaintenanceStatus;
